@@ -606,9 +606,12 @@ def map_parsed_data(parsing_spec, parsing_data):
               log.debug("Calling plugin '[green]{}[/green]' for key '{}' in " \
                         "document {}".format(plugin_id, key, document_id))
               params = plugin_call['params'] if 'params' in plugin_call  else {}
-              if not plugin.process(parsing_spec, parsing_data, nodes, **params):
-                log.warn("Plugin '{}' finished with issues for key '{}' and nodes: {}".format(
-                          plugin_id, key, nodes))
+              if not 'enabled' in params or params['enabled'] == True:
+                if not plugin.process(parsing_spec, parsing_data, nodes, **params):
+                  log.warn("Plugin '{}' finished with issues for key '{}' and nodes: {}".format(
+                            plugin_id, key, nodes))
+              else:
+                log.debug("Ignoring plugin '[green]{}[/green]'".format(plugin_id))
 
           # add the mapped nodes for the current key
           parsing_data['mappings'][map_key].extend(nodes)
@@ -683,11 +686,14 @@ def curate_data(process_stage, parsing_spec, parsing_data):
       # call the process function of this plugin
       log.debug("Calling plugin '[green]{}[/green]'".format(plugin_id))
       params = plugin_call['params'] if 'params' in plugin_call  else {}
-      if plugin.process(parsing_spec, parsing_data, **params):
-        log.debug("The execution of '{}' was successful".format(plugin_id))
+      if not 'enabled' in params or params['enabled'] == True:
+        if plugin.process(parsing_spec, parsing_data, **params):
+          log.debug("The execution of '{}' was successful".format(plugin_id))
+        else:
+          log.error("Plugin '{}' finished with errors".format(plugin_id))
+          return False
       else:
-        log.error("Plugin '{}' finished with errors".format(plugin_id))
-        return False
+        log.debug("Ignoring plugin '[green]{}[/green]'".format(plugin_id))
 
   return True
 
@@ -731,14 +737,17 @@ def transform_parsed_data(parsing_spec,
       plugin_name   = list(plugin_call.values())[0]
       plugin_id = "{}.{}".format(plugin_group,plugin_name)
       plugin = plugins[plugin_group][plugin_name]
-      # call the process function of each plugin
-      log.debug("Calling plugin '[green]{}[/green]'".format(plugin_id))
       params = plugin_call['params'] if 'params' in plugin_call  else {}
-      if plugin.process(parsing_spec, parsing_data, output_info, **params):
-        log.debug("The execution of '{}' was successful".format(plugin_id))
+      if not 'enabled' in params or params['enabled'] == True:
+        # call the process function of each plugin
+        log.debug("Calling plugin '[green]{}[/green]'".format(plugin_id))
+        if plugin.process(parsing_spec, parsing_data, output_info, **params):
+          log.debug("The execution of '{}' was successful".format(plugin_id))
+        else:
+          log.error("Plugin '{}' finished with errors".format(plugin_id))
+          return False
       else:
-        log.error("Plugin '{}' finished with errors".format(plugin_id))
-        return False
+        log.debug("Ignoring plugin '[green]{}[/green]'".format(plugin_id))
 
   except pluginlib.PluginImportError as e:
       if e.friendly:
@@ -870,16 +879,19 @@ def process_datasets(file_parsing_spec, file_output, file_datasets):
       log.info("{} lines scanned".format(parsing_data['stats']['lines']))
 
     # curate parsed data according to the spec
+    log.info("Executing [green]<curation>[/green] ([yellow]before_mapping[/yellow]) plugins")
     if not curate_data('before_mapping', parsing_spec, parsing_data):
       log.error("Unexpected error curating mapped data")
       return False
 
     # map whole parsed data according to the spec
+    log.info("Executing [green]<mapping>[/green] plugins")
     if not map_parsed_data(parsing_spec, parsing_data):
       log.error("Unexpected error mapping parsed data")
       return False
 
     # curate mapped data according to the spec
+    log.info("Executing [green]<curation>[/green] ([yellow]after_mapping[/yellow]) plugins")
     if not curate_data('after_mapping', parsing_spec, parsing_data):
       log.error("Unexpected error curating mapped data")
       return False
@@ -888,6 +900,7 @@ def process_datasets(file_parsing_spec, file_output, file_datasets):
     parsing_data.dump()
 
     # transform whole parsed data according to the requested output type
+    log.info("Executing [green]<transforming>[/green] plugins")
     if not transform_parsed_data(parsing_spec,
                                 parsing_data,
                                 output_info):
